watch method

  1. @override
Stream<List<MoleDataEntry>> watch()
override

Live snapshot stream of all entries in this source.

Emits the current full list immediately on subscription and again on every change.

Implementation

@override
Stream<List<MoleDataEntry>> watch() => _stream.stream;