watch method
Live snapshot stream of all entries in this source.
Emits the current full list immediately on subscription and again on every change.
Implementation
@override
Stream<List<MoleDataEntry>> watch() => _stream.stream;
Live snapshot stream of all entries in this source.
Emits the current full list immediately on subscription and again on every change.
@override
Stream<List<MoleDataEntry>> watch() => _stream.stream;